@@ -1,12 +1,12 @@
+from django.core.exceptions import NON_FIELD_ERRORS
 from django.forms.forms import BaseForm
 from django.forms.widgets import MediaDefiningClass
 from django.forms.utils import ErrorDict, ErrorList, RenderableMixin
 from django.utils.datastructures import MultiValueDict
-from django.utils.functional import cached_property
 
 from formset.exceptions import FormCollectionError
 from formset.renderers.default import FormRenderer
-from formset.utils import FormMixin
+from formset.utils import HolderMixin, FormMixin, FormsetErrorList
 
 
 MARKED_FOR_REMOVAL = '_marked_for_removal_'
@@ -25,6 +25,7 @@ class FormCollectionMeta(MediaDefiningClass):
                 setattr(value, '_name', key)
                 if isinstance(value, BaseForm) and not isinstance(value, FormMixin):
                     value.__class__ = type(value.__class__.__name__, (FormMixin, value.__class__), {})
+                    value.error_class = FormsetErrorList
                 attrs['declared_holders'][key] = value
 
         new_class = super().__new__(cls, name, bases, attrs)
@@ -46,11 +47,11 @@ class FormCollectionMeta(MediaDefiningClass):
         return new_class
 
 
-class BaseFormCollection(RenderableMixin):
+class BaseFormCollection(HolderMixin, RenderableMixin):
     """
     The main implementation of all the FormCollection logic.
     """
-    default_renderer = FormRenderer
+    default_renderer = None
     prefix = None
     template_name = 'formset/default/collection.html'
     min_siblings = None
@@ -69,7 +70,7 @@ class BaseFormCollection(RenderableMixin):
         if max_siblings is not None:
             self.max_siblings = max_siblings
         if extra_siblings is not None:
-            self.extra_siblings = max_siblings
+            self.extra_siblings = extra_siblings
         if self.has_many:
             if self.min_siblings is None:
                 self.min_siblings = 1
@@ -92,7 +93,8 @@ class BaseFormCollection(RenderableMixin):
                 initial = self.initial.get(name)
             if initial is None:
                 initial = declared_holder.initial
-            holder = declared_holder.__class__(initial=initial, prefix=prefix, renderer=self.renderer)
+            holder = declared_holder.replicate(initial=initial, prefix=prefix, renderer=self.renderer)
+            holder.is_single = True
             yield holder
 
     def iter_many(self):
@@ -114,7 +116,7 @@ class BaseFormCollection(RenderableMixin):
                     initial = self.initial[position].get(name)
                 if initial is None:
                     initial = declared_holder.initial
-                holder = declared_holder.__class__(initial=initial, prefix=prefix, renderer=self.renderer)
+                holder = declared_holder.replicate(initial=initial, prefix=prefix, renderer=self.renderer)
                 holder.position = position
                 if item_num == first:
                     holder.is_first = True
@@ -130,10 +132,11 @@ class BaseFormCollection(RenderableMixin):
                 position = f'${{position_{count}}}' if count > 0 else '${position}'
                 prefix = f'{self.prefix}.{position}.{name}'
             else:
+                position = '${position}'
                 prefix = f'${{position}}.{name}'
-            holder = declared_holder.__class__(prefix=prefix, renderer=self.renderer)
+            holder = declared_holder.replicate(prefix=prefix, renderer=self.renderer)
             holder.is_template = True
-            holder.position = '${position}'
+            holder.position = position
             if item_num == first:
                 holder.is_first = True
             if item_num == last:
@@ -171,22 +174,30 @@ class BaseFormCollection(RenderableMixin):
                     continue
                 cleaned_data = {}
                 for name, declared_holder in self.declared_holders.items():
-                    holder = declared_holder.__class__(data=data.get(name))
+                    holder = declared_holder.replicate(data=data.get(name))
                     if holder.is_valid():
                         cleaned_data[name] = holder.cleaned_data
                     else:
                         self._errors.extend([{}] * (index - len(self._errors)))
-                        self._errors.append({name: holder.errors.data})
+                        self._errors.append({name: holder.errors})
                 self.cleaned_data.append(cleaned_data)
+            if len(self.cleaned_data) < self.min_siblings:
+                # can only happen, if the client bypasses browser control
+                self._errors.clear()
+                self._errors.append({NON_FIELD_ERRORS: ["Too few siblings."]})
+            if self.max_siblings and len(self.cleaned_data) > self.max_siblings:
+                # can only happen, if the client bypasses browser control
+                self._errors.clear()
+                self._errors.append({NON_FIELD_ERRORS: ["Too many siblings."]})
         else:
             self.cleaned_data = {}
             self._errors = ErrorDict()
             for name, declared_holder in self.declared_holders.items():
-                holder = declared_holder.__class__(data=self.data.get(name))
+                holder = declared_holder.replicate(data=self.data.get(name))
                 if holder.is_valid():
                     self.cleaned_data[name] = holder.cleaned_data
                 else:
-                    self._errors.update({name: holder.errors.data})
+                    self._errors.update({name: holder.errors})
 
     def clean(self):
         return self.cleaned_data
@@ -198,6 +209,14 @@ class BaseFormCollection(RenderableMixin):
         """
         return not (self.min_siblings is None and self.max_siblings is None and self.extra_siblings is None)
 
+    def render(self, template_name=None, context=None, renderer=None):
+        if not (renderer or self.renderer):
+            renderer = FormRenderer()
+        return super().render(template_name, context, renderer)
+
+    __str__ = render
+    __html__ = render
+
 
 class FormCollection(BaseFormCollection, metaclass=FormCollectionMeta):
     """
