@@ -2,6 +2,8 @@ from formset.renderers.default import FormRenderer as DefaultFormRenderer
 
 
 class FormRenderer(DefaultFormRenderer):
+    max_options_per_line = 4
+
     def __init__(self, **kwargs):
         kwargs.setdefault('label_css_classes', 'form-label')
         super().__init__(**kwargs)
@@ -41,8 +43,11 @@ class FormRenderer(DefaultFormRenderer):
         return context
 
     def _amend_collection(self, context):
-        context['add_collection_button'] = 'formset/bootstrap/buttons/add_collection.html'
-        context['remove_collection_button'] = 'formset/bootstrap/buttons/remove_collection.html'
+        context.update({
+            'add_collection_button': 'formset/bootstrap/buttons/add_collection.html',
+            'remove_collection_button': 'formset/bootstrap/buttons/remove_collection.html',
+            'css_classes': self.collection_css_classes,
+        })
         return context
 
     _context_modifiers = dict(DefaultFormRenderer._context_modifiers, **{
