@@ -5,7 +5,7 @@ from django.forms.renderers import DjangoTemplates
 
 
 class FormRenderer(DjangoTemplates):
-    max_options_per_line = 4
+    max_options_per_line = 0
 
     _template_mapping = {
         'django/forms/errors/list/default.html': 'formset/default/field_errors.html',
@@ -16,11 +16,12 @@ class FormRenderer(DjangoTemplates):
     }
 
     def __init__(self, field_css_classes=None, label_css_classes=None, control_css_classes=None,
-                 form_css_classes=None, max_options_per_line=None):
+                 form_css_classes=None, collection_css_classes=None, max_options_per_line=None):
         self.field_css_classes = field_css_classes
         self.label_css_classes = label_css_classes
         self.control_css_classes = control_css_classes
         self.form_css_classes = form_css_classes
+        self.collection_css_classes = collection_css_classes
         if max_options_per_line is not None:
             self.max_options_per_line = max_options_per_line
         super().__init__()
@@ -42,9 +43,11 @@ class FormRenderer(DjangoTemplates):
                 context['attrs'] = {}
             context['attrs']['class'] = self.label_css_classes
         if hide_checkbox_label and context['field'].widget_type == 'checkbox':
-            # label is rendered by {{ field }}, so remove it to prevent double rendering
-            context['use_tag'] = False
+            # `<label>Label:</label>` is rendered by `{{ field }}`, so remove it to
+            # prevent double rendering.
             context.pop('label', None)
+            context['attrs'].pop('for', None)
+            context['use_tag'] = bool(self.control_css_classes)
         return context
 
     def _amend_multiple_input(self, context):
@@ -61,8 +64,11 @@ class FormRenderer(DjangoTemplates):
         return context
 
     def _amend_collection(self, context):
-        context['add_collection_button'] = 'formset/default/buttons/add_collection.html'
-        context['remove_collection_button'] = 'formset/default/buttons/remove_collection.html'
+        context.update({
+            'add_collection_button': 'formset/default/buttons/add_collection.html',
+            'remove_collection_button': 'formset/default/buttons/remove_collection.html',
+            'css_classes': self.collection_css_classes,
+        })
         return context
 
     _context_modifiers = {
