@@ -2,7 +2,6 @@ from django import template
 from django.forms import BaseForm
 from django.middleware.csrf import get_token
 from django.template.exceptions import TemplateSyntaxError
-from django.utils.html import format_html_join
 from django.utils.module_loading import import_string
 
 from formset.utils import FormMixin, FormsetErrorList
@@ -16,10 +15,12 @@ def _formsetify(form, *args, **kwargs):
         form.__class__ = type(form.__class__.__name__, (FormMixin, form.__class__), {})
 
     renderer_args = [
+        ('form_css_classes', kwargs.pop('form_classes', None)),
         ('field_css_classes', kwargs.pop('field_classes', None)),
         ('label_css_classes', kwargs.pop('label_classes', None)),
         ('control_css_classes', kwargs.pop('control_classes', None)),
         ('form_css_classes', kwargs.pop('form_classes', None)),
+        ('collection_css_classes', kwargs.pop('collection_classes', None)),
         ('max_options_per_line', kwargs.pop('max_options_per_line', None)),
     ]
     if len(kwargs):
@@ -38,24 +39,18 @@ def _formsetify(form, *args, **kwargs):
     return form
 
 
-def _form_attrs(context, form, *args, **kwargs):
+def formsetify(context, form, *args, **kwargs):
     get_token(context['request'])  # ensures that the CSRF-Cookie is set
-    form = _formsetify(form, *args, **kwargs)
-    attrs = []
-    form_name = getattr(form, 'name', None)
-    if form_name:
-        attrs.append(('name', form_name))
-    if form.form_id:
-        attrs.append(('id', form.form_id))
-    return format_html_join('', ' {0}="{1}"', attrs)
+    _formsetify(form, *args, **kwargs)
+    return ''
 
 
-def _render_form(context, form, *args, **kwargs):
+def render_form(context, form, *args, **kwargs):
     get_token(context['request'])  # ensures that the CSRF-Cookie is set
     form = _formsetify(form, *args, **kwargs)
     return str(form)
 
 
 register = template.Library()
-register.simple_tag(_form_attrs, name='form_attrs', takes_context=True)
-register.simple_tag(_render_form, name='render_form', takes_context=True)
+register.simple_tag(formsetify, name='formsetify', takes_context=True)
+register.simple_tag(render_form, name='render_form', takes_context=True)
